"""
Turtleグラフィックスを継承したKameクラス．
メンバ関数として，Sierpinskiの三角形を描く関数を持つ．
"""

from turtle import Turtle

class Kame(Turtle): 
    """Turtleクラスを継承したKameクラスを定義
    """
    def __init__(self):
        super().__init__()
        self.shape('turtle')
        self.speed(0)
    
    def triangle(self, size):
        """ 三角形を描く
        Args:
            size: １辺の長さ
        """
        self.begin_fill()
        self.pd()
        self.fd(size)
        self.lt(120)
        self.fd(size)
        self.lt(120)
        self.fd(size)
        self.pu()
        self.lt(120)
        self.end_fill()

    def sierpinski(self, size):
        """ シェルピンスキーの三角形を描く
	
        1辺の長さが20以上なら，3つの三角形に分割することを再帰的に繰り返す．
        
        Args:
            size: １辺の長さ
        """
        if size<20.0:
            self.triangle(size)
            return
        else:
            self.sierpinski(size/2.0)
            self.fd(size/2.0)
            self.sierpinski(size/2.0)
            self.lt(120)
            self.fd(size/2.0)
            self.rt(120)
            self.sierpinski(size/2.0)
            self.rt(120)
            self.fd(size/2.0)
            self.lt(120) 

if __name__ == '__main__':
    kame = Kame()
    kame.triangle(100)
    kame.speed(0)
    kame.color('red', 'pink')
    kame.sierpinski(100)

    kame.screen.mainloop()
