"""
東京電力で公開されている
<2022年4月以降>の「過去の電力使用実績データ」を解析するために
Zipで圧縮された複数のCSVファイルを解凍しながら読み込む
"""
#%%
import os
import pandas as pd
import zipfile
import matplotlib.pyplot as plt

#%%
# Zipファイルに含まれるファイル名一覧を取得
zf = zipfile.ZipFile('Data/202302_power_usage.zip')
files = zf.namelist()
print(files) #１日ごとのCSVファイル一覧

#%%
"""
CSVファイルの中身を確認
最初のCSVファイルの前半を読み込む
"""
df = pd.read_csv(
        zf.open(files[0]), #Zipファイル内の最初のファイルを開く
        skiprows=13, #13行とばす
        nrows=24, #24行読み込む（1時間毎のデータ）
        encoding='shift-jis')
print(df)

#%%
"""
CSVファイルの中身を確認
最初のCSVファイルの後半（54行目以降,5分毎のデータ）を読み込む
"""
dfm = pd.read_csv(
        zf.open(files[0]), 
        skiprows=54, #54行とばす．
        nrows=288, #288行読み込む（5分毎のデータ．(60/5)x24=288）
        encoding='shift-jis')
print(dfm)


#%%
"""
全Zipファイルを読み込む
"""
# Dataフォルダ内のファイル一覧を取得
basedir = 'Data'
targets = os.listdir(basedir)
print(targets)

#%%
# １時間毎の電力使用量データ部を読み込む
dfs = []
for tgt in targets:
    if tgt.endswith('.zip'): # zipファイルなら
        zipfilepath = os.path.join(basedir, tgt)

        with zipfile.ZipFile(zipfilepath) as zf:
            csvfiles = zf.namelist()
            for file in csvfiles:
                print(file)
                df = pd.read_csv(
                        zf.open(file), 
                        skiprows=13, 
                        nrows=24, 
                        encoding='shift-jis')
                dfs.append(df)

# すべてのデータフレームを連結
dfall = pd.concat(dfs).reset_index(drop=True)

print(dfall.tail())

#%%
dfall['当日実績(万kW)'].plot()
plt.show()

# %%
"""
演習課題
全期間の１週間毎の平均電力使用量をグラフ化する
"""
