"""
openpyxl を使った，Excelファイル（ワークブック）の新規作成
・シートの追加
・選択したシートで，セルに値を代入
・シート名の変更

openpyxl のインストール
(Anaconda/Miniconda) conda install openpyxl
(それ以外) pip install openpyxl
"""

#%%

# カレントディレクトリを取得し，ファイルの入出力場所（work_dir）を指定する
import os
from getWorkingDir import getWorkDir

work_dir = getWorkDir("Sample2_7_openpyxl")

output_path = os.path.join(work_dir, 'myworkbook.xlsx')  # 保存するExcelファイルのパス
print(output_path)


#%%
from openpyxl import Workbook

# ワークブックの新規作成
wb = Workbook()

# workbook は sheet の集まり
for sheet in wb:
    # デフォルトのシート名は "Sheet"
    print(f'default sheet name: {sheet.title}')

#%%
# ワークシートの追加
wb.create_sheet('new sheet')
wb.create_sheet('new sheet')
wb.create_sheet('new sheet', 0) #最初のシートとして
#同じ名前のシートを追加しようとすると，2枚目以降に数字がつく．

# ワークシートの列挙
for sheet in wb:
    print(f'current sheet name: {sheet.title}')

#%%
# ワークシートの選択
ws = wb.active  # アクティブなワークシートを選択．未指定の場合最初のシート
print(f"Active Sheet is {ws.title}")

#%%
# セルに値を代入
ws['A1'] = 'Hello A1'

# 別のシートを指定
ws = wb['Sheet']
ws['B2'] = 'Hello B2'

#各セルに値を代入
ws = wb['new sheet1']
for i in range(1, 20):
    ws.cell(row = i, column = 1, value = i)
    ws.cell(row = i, column = 2, value = -i)

# 九九の表
ws = wb['new sheet2']
ws.title = "19x9" #シート名を変更
for j in range(1, 20):
    for k in range(1, 10):
        ws.cell(row = j, column = k, value = j*k)

# ワークブックを保存
wb.save(output_path) 
wb.close()

# %%
