"""
事前に excel1_create.py を実行し， 
myworkbook.xlsx ファイルが有る状態で実行すること

・既存のExcelファイルを開く
・セルを参照して値を取得
・セルに計算式を代入する．（注意：計算が行われるのはファイルがExcelで開かれたとき．）
"""

#%%
# カレントディレクトリを取得し，ファイルの入出力場所（work_dir）を指定する
import os
from getWorkingDir import getWorkDir

work_dir = getWorkDir("Sample2_7_openpyxl")

load_path = os.path.join(work_dir, 'myworkbook.xlsx')  # 読み込むExcelファイルのパス
print(load_path)


#%%
from openpyxl import load_workbook
from openpyxl.utils.cell import get_column_letter

# ワークブックの読み込み
wb = load_workbook(load_path)

for sheet in wb:
    print(f'sheet name: {sheet.title}')

ws = wb.active #アクティブなセル．未指定なら最初のシート
print(f'Active sheet : {ws.title}')

# セルの値の表示
print(f"[A1] cell is {ws['a1'].value}") 


#%%
# ワークシートの全セルを反復（行ごと）
ws = wb['19x9']
for row in ws.rows: # 各行についてループ
    for cell in row: # 1行の各セルについてループ
        print(f"{cell.value:3d}", end=" " ) #整数3桁表示。改行なし。
    print("") # 改行


#%%
# データのあるセルの範囲を調べる
r_min = ws.min_row
r_max = ws.max_row
c_min = ws.min_column
c_max = ws.max_column

c_min_name = get_column_letter(c_min)
c_max_name = get_column_letter(c_max)

print(f"Rows: {r_min}-{r_max}")
print(f"Columns: {c_min}({c_min_name}) - {c_max}({c_max_name})")


#%%
c_sum_name = get_column_letter(c_max+1)

# 計算式をセルに代入．J列（10列目）に各行の合計を求める．
for i in range(r_min, r_max+1):
    ws.cell(
            row = i, 
            column = c_max+1, 
            value = f"=SUM({c_min_name}{i}:{c_max_name}{i})"
            )

# 計算式のセルを参照しても，式が得られるだけ．計算結果は取得できない．
tgt_cell = f"{c_sum_name}1"
print(f"[1] {tgt_cell} is {ws[tgt_cell].value}")

# 一度ファイル保存して，Excelで開くと計算が実行される
saveFileName = os.path.join(work_dir, 'myworkbook2.xlsx')
wb.save(saveFileName)
wb.close()


#%%
# そのまま開くと、計算式が取得されｒ
wb2 = load_workbook(saveFileName)

ws2 = wb2['19x9']
print(f"[2] {tgt_cell} is {ws2[tgt_cell].value}")
wb2.close()


#%%
# dataonly=True で値を取得するが、Excelで開く前だとまだ計算が行われていない．
wb3 = load_workbook(saveFileName, data_only=True)

ws3 = wb3['19x9']
print(f"[3] {tgt_cell} is {ws3[tgt_cell].value}")
wb3.close()


#%%
# Excelで開き，myworkbook2a.xlsxとして名前をつけて保存してから開くと，計算されている．

targetfile = os.path.join(work_dir, 'myworkbook2a.xlsx')

if os.path.exists(targetfile):
    # ファイルが存在していれば
    wb4 = load_workbook(targetfile, data_only=True)

    ws4 = wb4['19x9']
    print(f"[4] {tgt_cell} is {ws4[tgt_cell].value}")
    wb4.close()
else:
    # ファイルが存在していなければ
    print("myworkbook2.xlsx をExcelで開き，myworkbook2a.xlsx と名前をつけて保存してから再度実行して下さい．")
# %%
