"""
pyautoguiを使って，Excelを起動し，セルの計算をさせてから保存する．

事前に excel1_create.py を実行し， 
myworkbook.xlsx ファイルが有る状態で実行すること
"""

#%%
# カレントディレクトリを取得し，ファイルの入出力場所（work_dir）を指定する
import os
from getWorkingDir import getWorkDir

work_dir = getWorkDir("Sample2_7_openpyxl")

load_path = os.path.join(work_dir, 'myworkbook.xlsx')  # 読み込むExcelファイルのパス
save_path = os.path.join(work_dir, 'myworkbook3.xlsx')


#%%
from openpyxl import load_workbook
from openpyxl.utils.cell import get_column_letter

# ワークブックの読み込み
wb = load_workbook(load_path)
ws =wb['19x9']

# データのあるセルの範囲を調べる
r_min = ws.min_row
r_max = ws.max_row
c_min = ws.min_column
c_max = ws.max_column

# 各列の平均を求める
for c in range(c_min, c_max + 1):
    col = get_column_letter(c) #列の名前（A,B,C,...）を取得
    ws.cell(
            row = r_max + 1, 
            column = c, 
            value = f"=AVERAGE({col}{r_min}:{col}{r_max})")

# 計算式のセルを参照しても，式が得られるだけ．計算結果は取得できない．
tgt_cell = f"{get_column_letter(c_max)}{r_max + 1}"
print(f"[1] {tgt_cell} is {ws[tgt_cell].value}")

# 一度ファイル保存して，Excelで開くと計算が実行される
wb.save(save_path)
wb.close()

#%%
# Excelで開く前だと，まだ計算が行われていないので，値はNone
wb2 = load_workbook(save_path, data_only=True)
ws2 = wb2['19x9']
print(f"[2] {tgt_cell} is {ws2[tgt_cell].value}")
wb2.close()

#%%
"""
PyAutoGUIを使って，先ほど保存したExcelファイルを開いて保存して閉じる．
"""
import pyautogui as pag

pag.PAUSE = 1 # 毎操作後１秒待つ

# Excelを起動(別の方法，ExcelのexeファイルのPathを指定する)
import subprocess
subprocess.Popen([r"C:\Program Files\Microsoft Office\root\Office16\EXCEL.EXE", save_path]) 
pag.sleep(4) #? Excelの起動を待機

# ファイルを保存して終了
pag.hotkey('ctrl', 's', interval=0.2) # Ctrl+s : 保存
pag.press('left') #「保護ビューでは保存が無効になっています」ダイアログ
pag.press('enter')
pag.sleep(1)
pag.hotkey('alt','f4', interval=0.2) # Alt-F4 : 終了


# %%

# Excelで保存済みファイルをdata_only=Trueで開き、計算結果を読み込む．
wb3 = load_workbook(save_path, data_only=True)
ws3 = wb3['19x9']
print(f"[3] {tgt_cell} is {ws3[tgt_cell].value}")
wb3.close()

# %%
