"""
torchvision に含まれている MNIST手書き数字データセットを読み込み，
手書き数字画像を数字ごとにフォルダに分けて保存する
"""
#%%
import numpy as np
import matplotlib.pyplot as plt
import os

from PIL import Image

from torch.utils.data import DataLoader
from torchvision import datasets
from torchvision.transforms import ToTensor

#%%
data_dir = "../data"
batch_size = 100

# MNISTデータセット
train_dataset = datasets.MNIST(data_dir, train=True, download=True, transform=ToTensor())

# data loader を準備
train_loader = DataLoader(dataset=train_dataset, batch_size=batch_size, shuffle=False)

#%%
# 画像の確認（1 batch = 100枚分）
for (data, target) in train_loader:
    print('data:', data.size(), 'type:', data.type())
    print('target:', target.size(), 'type:', target.type())

    # MNIST 手書き数字画像を表示
    plt.figure(figsize=(10, 10))

    for i in range(100):
        plt.subplot(10,10,i+1)
        plt.axis('off')
        plt.imshow(data[i,:,:,:].numpy().reshape(28,28), cmap="gray")
        plt.title(str(target[i].item()))

    plt.tight_layout()
    plt.show()

    break

#%%
base_dir = "./images"
os.makedirs(base_dir, exist_ok=True)

# 各数字の個数を数える
count = []
for i in range(10):
    os.makedirs(os.path.join(base_dir, str(i)), exist_ok=True)
    count.append(0)

for (data, target) in train_loader:
    for i in range(batch_size):
        image = data[i,:,:,:].numpy().reshape(28,28)
        num = target[i].item()
        pil_image = Image.fromarray((image*255).astype(np.uint8))
        tgt_filepath = os.path.join(base_dir, f"{num}", f"{count[num]:03d}.png")
        pil_image.save(tgt_filepath)
        count[num] += 1
    
    print(count)

    # 一番少ないクラス（数字）が100個を超えたら終了
    if min(count)>100:
        break

# %%
