"""
先に treat_excel1.py を実行し， 
myworkbook.xlsx ファイルが有る状態で実行すること

・既存のExcelファイルを開く
・セルを参照して値を取得
・セルに計算式を代入する．（注意：計算が行われるのはファイルがExcelで開かれたとき．）
"""

#%%
# カレントディレクトリを取得し，ファイルの入出力場所（work_dir）を指定する
import os
from getWorkingDir import getWorkDir

work_dir = getWorkDir("Sample2_7_openpyxl")

load_path = os.path.join(work_dir, 'myworkbook.xlsx')  # 読み込むExcelファイルのパス
print(load_path)

#%%
from openpyxl import load_workbook

# ワークブックの読み込み
wb = load_workbook(load_path)

for sheet in wb:
    print(f'sheet name: {sheet.title}')

#%%
ws = wb.active #アクティブなセル．未指定なら最初のシート
print(f'Active sheet : {ws.title}')

# セルの値の表示
print(f"[A1] cell is {ws['a1'].value}") 

# ワークシートの全セルを反復（行ごと）
ws = wb['9x9']
for row in ws.rows:
    for cell in row:
        print(f"{cell.value:2d}", end=" " )
    print("") # 改行

#%%
# データの範囲
min_row = ws.min_row
max_row = ws.max_row
min_col = ws.min_column
max_col = ws.max_column
print(f"data range: rows:({min_row},{max_row}), columns:({min_col},{max_col})")

# 範囲を指定
print("rows:(3,5), cols:(7,9)")
for row in ws.iter_rows(min_row=3, max_row=5, min_col=7, max_col=9):
    for cell in row:
        print(f"{cell.value:2d}", end=" ")
    print("")

#%%
# １行ずつ，値を取得する
for row in ws.iter_rows(values_only=True):
    print(row)

#%%
# １列ずつ，値を取得
for column in ws.iter_cols(values_only=True):
    print(column)


#%%
# セル範囲の取得
roi = ws['A1':'C6']
print(roi)

# 範囲内の値を列挙
values = []
for row in roi:
    tmp = []
    for col in row:
        tmp.append(col.value)
    values.append(tmp)

print(values)

#%%
# 同じことを１行で記述
values = [[col.value for col in row] for row in roi]
print(values)

#%%
# 計算式をセルに代入．J列（10列目）に各行の合計を求める．
for i in range(1, 10):
    ws.cell(row = i, column = 10, value = f"=SUM(A{i}:I{i})")

# 計算式のセルを参照しても，式が得られるだけ．計算結果は取得できない．
print(f"[1] J1 is {ws['J1'].value}")

# 一度ファイル保存して，Excelで開くと計算が実行される
saveFileName = os.path.join(work_dir, 'myworkbook2.xlsx')
wb.save(saveFileName)
wb.close()

#%%
# Excelで開く前だと，まだ計算が行われていない．
wb2 = load_workbook(saveFileName, data_only=True)

ws2 = wb2['9x9']
print(f"[2] J1 is {ws2['J1'].value}")
wb2.close()

#%%
# Excelで開き，myworkbook2a.xlsxとして名前をつけて保存してから開くと，計算されている．

targetfile = os.path.join(work_dir, 'myworkbook2a.xlsx')

if os.path.exists(targetfile):
    # ファイルが存在していれば
    wb2 = load_workbook(targetfile, data_only=True)

    ws2 = wb2['9x9']
    print(f"[3] J1 is {ws2['J1'].value}")
    wb2.close()
else:
    # ファイルが存在していなければ
    print("myworkbook2.xlsx をExcelで開き，myworkbook2a.xlsx と名前をつけて保存してから再度実行して下さい．")
# %%
