"""
pyautoguiを使って，Excelを起動し，セルの計算をさせてから保存する．

事前に excel1_create.py を実行し， 
myworkbook.xlsx ファイルが有る状態で実行すること
"""

#%%
import os
from openpyxl import load_workbook
from openpyxl.utils import get_column_letter
from getWorkingDir import getWorkDir

work_dir = getWorkDir("Sample2_7_openpyxl")

load_filepath = os.path.join(work_dir, 'myworkbook.xlsx')
save_filepath = os.path.join(work_dir, 'myworkbook3.xlsx')

#%%
# ワークブックの読み込み
wb = load_workbook(load_filepath)

# ワークシートを選択
ws = wb['9x9']

# 各列の平均を求める
for i in range(1,10):
    col = get_column_letter(i) #列の名前（A,B,C,...）を取得
    ws.cell(row = 10, column = i, value = f"=AVERAGE({col}1:{col}9)")

# 計算式のセルを参照しても，式が得られるだけ．計算結果は取得できない．
print(f"[1] I10 is {ws['i10'].value}")

# 一度ファイル保存して，Excelで開くと計算が実行される
wb.save(save_filepath)
wb.close()

#%%
# Excelで開く前だと，まだ計算が行われていないので，値はNone
wb2 = load_workbook(save_filepath, data_only=True)

ws2 = wb2['9x9']
print(f"[2] I10 is {ws2['i10'].value}")
wb2.close()

#%%
"""
PyAutoGUIを使って，先ほど保存したExcelファイルを開いて保存して閉じる．
"""
import pyautogui as pag

pag.PAUSE = 1 # 毎操作後１秒待つ

# Excelを起動(別の方法，ExcelのexeファイルのPathを指定する)
import subprocess
subprocess.Popen([r"C:\Program Files\Microsoft Office\root\Office16\EXCEL.EXE", save_filepath]) 
pag.sleep(4) #? Excelの起動を待機

# ファイルを保存して終了
pag.hotkey('ctrl', 's', interval=0.2) # Ctrl+s : 保存
pag.press('left') #「保護ビューでは保存が無効になっています」ダイアログ
pag.press('enter')
pag.sleep(1)
pag.hotkey('alt','f4', interval=0.2) # Alt-F4 : 終了


# %%

# 読み込み時に，data_only=True として，計算結果を読み込む必要がある．
wb3 = load_workbook(save_filepath, data_only=True)

ws3 = wb3['9x9']
print(f"[3] I10 is {ws3['i10'].value}")
wb3.close()

# %%
