"""
Excelでグラフを描く
"""
#%%
import os
from openpyxl import load_workbook
from openpyxl.chart import Reference, LineChart, BarChart

from getWorkingDir import getWorkDir

work_dir = getWorkDir("Sample2_7_openpyxl")

load_filepath = os.path.join(work_dir, "cloth_sales.xlsx")
save_filepath = os.path.join(work_dir, "sample_5B.xlsx")

print(load_filepath, save_filepath)

#%%
# ワークブックの読み込み
wb = load_workbook(load_filepath, data_only=True)
ws = wb.active

#
rmin = ws.min_row
rmax = ws.max_row
cmin = ws.min_column
cmax = ws.max_column

print(f"Rows:[{rmin},{rmax}], Columns:[{cmin},{cmax}]")

#データ範囲．最初の列のカテゴリー名は除外
data = Reference(ws, min_col=cmin+1, min_row=rmin, max_col=cmax, max_row=rmax) 

#ラベルの指定．
labels = Reference(ws, min_col=cmin, min_row=rmin+1, max_row=rmax)  # 項目名の設定

#折れ線グラフ
chart = LineChart()
chart.add_data(data, titles_from_data=True)
chart.set_categories(labels)
chart.title = 'Line Chart'  # グラフタイトル
chart.x_axis.title = 'TYPES'  # 軸ラベル
chart.y_axis.title = 'SALES'
chart.anchor = 'A14'  # グラフの表示位置
chart.width = 14  # グラフのサイズ
chart.height = 8
ws.add_chart(chart)


#棒グラフ
chart = BarChart()
chart.add_data(data, titles_from_data=True)
chart.set_categories(labels)
chart.title = 'Bar Chart'  # グラフタイトル
chart.x_axis.title = 'TYPES'  # 軸ラベル
chart.y_axis.title = 'SALES'
chart.anchor = 'A34'  # グラフの表示位置
chart.width = 14  # グラフのサイズ
chart.height = 8
ws.add_chart(chart)


#積み上げ棒グラフ
chart = BarChart()
chart.add_data(data, titles_from_data=True)
chart.set_categories(labels)
chart.title = 'Stacked Bar Chart (Style 1)'  # グラフタイトル

#! 積み上げ棒グラフにする
chart.type = 'col'
chart.grouping = "stacked"
chart.overlap = 100

#? スタイルを指定する
chart.style = 1

chart.x_axis.title = 'TYPES'  # 軸ラベル
chart.y_axis.title = 'SALES'
chart.anchor = 'A52'  # グラフの表示位置
chart.width = 14  # グラフのサイズ
chart.height = 8
ws.add_chart(chart)


# スタイルを変えたグラフを全部表示してみる．
for i in range(2, 49):
    #積み上げ棒グラフ
    chart = BarChart()
    chart.add_data(data, titles_from_data=True)
    chart.set_categories(labels)
    chart.title = f'Stacked Bar Chart (Style{i})'  # グラフタイトル
    chart.type = 'col'
    chart.grouping = "stacked"
    chart.overlap = 100
    chart.style = i
    chart.x_axis.title = 'TYPES'  # 軸ラベル
    chart.y_axis.title = 'SALES'
    chart.anchor = f'A{18*i+34}'  # グラフの表示位置
    chart.width = 14  # グラフのサイズ
    chart.height = 8
    ws.add_chart(chart)

wb.save(save_filepath)
# %%
