"""
兵庫県播磨町のHPで公開されている，播磨町の人口データをダウンロードする．
https://www.town.harima.lg.jp/chosejoho/tokejoho/jinko/index.html
・R3-1月はファイル名が nennrei ではなく nenrei になっているためエラーになる
・10月以降のファイル名が数字5桁になっている年が何年かある
"""

import os
import time
import urllib.request
from urllib.error import HTTPError

#播磨町人口データPDFが置かれているURL
url_base = "https://www.town.harima.lg.jp/kikaku/chosejoho/tokejoho/jinko/documents/"

def download_file(target_url, save_filepath):
    """target_urlに示されるPDFファイルをダウンロードする．
    Return:
        True: 成功
        False: 失敗（404error）
    """
    time.sleep(1) #相手方に負荷にならないように1秒待ってから
    try:
        urllib.request.urlretrieve(target_url, save_filepath)
    except HTTPError as err:
        if err.code == 404:
            print(f"Cannot find {os.path.basename(target_url)}")
            return False
    
    return True

os.makedirs("./PdfData", exist_ok=True)

for year in range(2,7): #R2～R6
    for month in range(1, 13): #1月～12月
        save_filepath = f"./PdfData/{year:02d}{month:02d}.pdf"

        if os.path.exists(save_filepath):
            # ダウンロード済みなら何もしない
            print(f"{save_filepath} already exists.")
        else:
            # ファイルが無いならダウンロードする
            target_url = url_base + f"r{year:02d}{month:02d}nennrei.pdf"
            print(target_url)

            if not download_file(target_url, save_filepath):
                #ダウンロードに失敗したとき
                target_url = ""
                if month>9: #10月以降が5桁になっている年があるので試す
                    target_url = url_base + f"r{year:02d}{month:03d}nennrei.pdf"
                if month==1: # R3-1月はnenrei.pdf になっている．
                    target_url = url_base + f"r{year:02d}{month:02d}nenrei.pdf"

                if len(target_url)>0:
                    print("retry", target_url)
                    download_file(target_url, save_filepath)
