"""
pdfminer.six を使用してPDFファイルからデータを読み取る
https://pdfminersix.readthedocs.io/en/latest/index.html
pip install pdfminer.six
conda install pdfminer.six

デジタルガバナンス・コード2.0
https://www.meti.go.jp/policy/it_policy/investment/dgc/dgc.html
"""

#%%
import os
from io import StringIO
from pdfminer.high_level import extract_text, extract_text_to_fp

# カレントディレクトリを取得する
cwd = os.getcwd()
print(f"Current Working Directory {cwd}")

if cwd.endswith("Sample2_9_pdfminer"):
    pdf_path = "dgc2.pdf"
    output_dir = 'imgs' 
    out_path = 'out.txt'
else:
    pdf_path = "Sample2_9_pdfminer/dgc2.pdf"
    output_dir = 'Sample2_9_pdfminer/imgs'
    out_path = 'Sample2_9_pdfminer/out.txt'


#%%
# 最初の2ページ分の文字を読み込む
text = extract_text(pdf_path, page_numbers=[1,2]) # 1,2ページを読み込み
print(f"{len(text)}文字")
print(text)


#%%
# 改行コードとスペースを取り除く
text = text.replace(chr(10), '') # 改行を取り除く
text = text.replace(' ', '') #スペースを取り除く
print(text) 


#%%
# 特定の単語の出現数を数える
for tgt in ['DX', 'SX', 'GX', 'AI', '技術', '経営']:
    print(f"{tgt} : {text.count(tgt)}")


#%%
# 全ページの読み込み，改行とスペースを取り除く
text = extract_text(pdf_path) # 全ページを読み込み
text = text.replace(chr(10), '') # 改行を取り除く
text = text.replace(' ', '') #スペースを取り除く
print(f"{len(text)}文字")
print(text)


#%%
# 特定の単語の出現数を数える
for tgt in ['DX', 'SX', 'GX', 'AI', '技術', '経営']:
    print(f"{tgt} : {text.count(tgt)}")


#%%
#PDFから読み込んだテキストデータをファイル(out.txt)に出力する
with open(pdf_path, 'rb') as fp_in, open(out_path, 'wb') as fp_out:
        extract_text_to_fp(fp_in, fp_out)


# %%
# PDF内の画像を抽出し，個別にファイルに保存する（output_dirを指定すると画像保存）
fp_out = StringIO() #出力バッファ
with open(pdf_path, 'rb') as fp_in:
    text = extract_text_to_fp(fp_in, fp_out, output_dir=output_dir)

# %%
